[postgis-tickets] [SCM] PostGIS branch stable-3.0 updated. 869a980a2df84f613c08f29e73d5be145474931c

git at osgeo.org git at osgeo.org
Mon Feb 3 01:03:57 PST 2020


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "PostGIS".

The branch, stable-3.0 has been updated
       via  869a980a2df84f613c08f29e73d5be145474931c (commit)
      from  3f21bfb473f63510f6ff0e8c00b4b1f78cafee5a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 869a980a2df84f613c08f29e73d5be145474931c
Author: Regina Obe <lr at pcorp.us>
Date:   Mon Feb 3 04:03:51 2020 -0500

    Backport change from master 3.1 - get rid of all references to svn, remove .git folder. References #4633 for PostGIS 3.0.1

diff --git a/make_dist.sh b/make_dist.sh
index 91f1ccb..0b20f84 100755
--- a/make_dist.sh
+++ b/make_dist.sh
@@ -33,32 +33,17 @@ if [ "$MAKE" = "" ]; then
     MAKE=make
 fi
 
-if [ -d ".git" ]; then
- git=yes
- # Extract tag from git or default to trunk
- tag=`git branch | grep \* | awk '{print $2}'`
-else
- git=no
- # Extract tag from svn or default to trunk
- tag=`svn info 2> /dev/null | grep ^URL | sed 's/.*\///'`
- [ -z "$tag" ] && tag=trunk
- [ "$tag" != "trunk" ] && tag=branches/$tag
-fi
+# Extract tag from git or default to trunk
+tag=`git branch | grep \* | awk '{print $2}'`
 
 if [ -n "$1" ]; then
   if [ "$1" = "-b" ]; then
     shift
-    if [ "$git" = "yes" ]; then
-      tag=svn-$1
-    else
-      tag="$1"
-      [ "$tag" != "trunk" ] && tag="branches/$tag"
-    fi
+    tag=svn-$1
     branch=yes
   else
+    tag=$1
     version="$1"
-    tag="tags/$version"
-    [ "$git" = "yes" ] && tag=$1
   fi
 fi
 
@@ -69,19 +54,7 @@ if [ -d "$outdir" ]; then
 	exit 1
 fi
 
-if [ "$git" = "no" ]; then
-  echo "Exporting tag $tag"
-  svnurl="http://svn.osgeo.org/postgis/$tag"
-  svn export $svnurl "$outdir"
-  if [ $? -gt 0 ]; then
-    exit 1
-  fi
-else
-  git clone -b $tag . $outdir || exit 1
-  #cd $outdir
-  #git checkout $tag || exit 1
-  #cd -
-fi
+git clone -b $tag . $outdir || exit 1
 
 echo "Removing make_dist.sh and HOWTO_RELEASE"
 rm -fv "$outdir"/make_dist.sh "$outdir"/HOWTO_RELEASE
@@ -92,14 +65,16 @@ owd="$PWD"
 cd "$outdir"
 ./autogen.sh
 ./configure ${CONFIGURE_ARGS}
-# generating postgis_svn_revision.h for >= 2.0.0 tags
-if test -f utils/svn_repo_revision.pl; then
-	echo "Generating postgis_svn_revision.h"
-	perl utils/svn_repo_revision.pl $svnurl
+# generating postgis_revision.h for >= 2.0.0 tags
+if test -f utils/repo_revision.pl; then
+	echo "Generating postgis_revision.h"
+	perl utils/repo_revision.pl
 fi
-#make
+# generate ChangeLog
+make ChangeLog
 cd "$owd"
 
+
 # generating comments
 echo "Generating documentation"
 owd="$PWD"
@@ -116,10 +91,10 @@ echo "Running make distclean"
 owd="$PWD"
 cd "$outdir"
 ${MAKE} distclean
-if [ "$git" = "yes" ]; then
-  echo "Removing .git dir"
-  rm -rf .git
-fi
+
+echo "Removing .git dir"
+rm -rf .git
+
 cd "$owd"
 
 # Find a better version name when fetching
@@ -129,8 +104,8 @@ if test "$version" = "dev"; then
   VMAJ=`grep ^POSTGIS_MAJOR_VERSION "$outdir"/Version.config | cut -d= -f2`
   VMIN=`grep ^POSTGIS_MINOR_VERSION "$outdir"/Version.config | cut -d= -f2`
   VMIC=`grep ^POSTGIS_MICRO_VERSION "$outdir"/Version.config | cut -d= -f2`
-  VREV=`cat "$outdir"/postgis_svn_revision.h | awk '{print $3}'`
-  version="${VMAJ}.${VMIN}.${VMIC}-r${VREV}"
+  VREV=`cat "$outdir"/postgis_revision.h | awk '{print $3}'`
+  version="${VMAJ}.${VMIN}.${VMIC}-${VREV}"
   #if newoutdir is not already set, then set it
   if test "x$newoutdir" = "x"; then
       newoutdir=postgis-${version}

-----------------------------------------------------------------------

Summary of changes:
 make_dist.sh | 61 ++++++++++++++++++------------------------------------------
 1 file changed, 18 insertions(+), 43 deletions(-)


hooks/post-receive
-- 
PostGIS


More information about the postgis-tickets mailing list